Environment Variables#
Development Variables#
These are used by the Vite dev server (set in .env):
Variable |
Description |
Default |
|---|---|---|
|
ArgoCD auth token cookie value for dev proxy (dev only) |
(required for dev) |
|
Filter to a specific ArgoCD project |
(none) |
|
ArgoCD hostname shown in login instructions |
|
|
Base URL prefix for API requests |
|
|
Version shown in header (set by CI from git tag) |
|
|
Auto-refresh interval in milliseconds |
|
Helm Chart Values#
Key configuration values for production deployment:
Value |
Description |
Default |
|---|---|---|
|
ArgoCD instance URL |
|
|
Container image repository |
|
|
Container image tag |
|
|
Number of pod replicas |
|
|
Kubernetes service type |
|
|
Service port |
|
|
Enable ingress |
|
|
Ingress class name |
|
|
Ingress hostname |
(none) |
|
Ingress annotations |
|
|
TLS configuration |
|
|
CPU limit |
|
|
Memory limit |
|
|
CPU request |
|
|
Memory request |
|